# -*- coding: utf-8 -*-

# empty module to bind functions

from .connections import (
    getUserSession, getPostInfo, getOfficialVideoPost, getInkeyData,
    getLivePlayInfo, getLiveStatus, getVodPlayInfo, getFVideoInkeyData,
    getPostComments, getPostStarComments, getFVideoPlayInfo
)
